// ************************************************************************** //
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Wrap/Swig/libBornAgainDevice.i
//! @brief     SWIG interface file for libBornAgainDevice
//!
//!            Configuration is done in Device/CMakeLists.txt
//!
//! @homepage  http://apps.jcns.fz-juelich.de/BornAgain
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2013
//! @authors   Scientific Computing Group at MLZ Garching
//
// ************************************************************************** //

%module(directors="1", moduleimport="import $module") "libBornAgainDevice"

%include "commons.i"

%include "../../auto/Wrap/doxygenDevice.i"

%{
#include "Base/Element/PolMatrices.h"
#include "Param/Distrib/ParameterDistribution.h"
#include "Device/Beam/Beam.h"
#include "Device/Beam/FootprintGauss.h"
#include "Device/Beam/FootprintSquare.h"
#include "Device/Data/DataUtils.h"
#include "Device/Detector/RectangularDetector.h"
#include "Device/Detector/SphericalDetector.h"
#include "Device/Histo/HistoUtils.h"
#include "Device/Histo/Histogram1D.h"
#include "Device/Histo/Histogram2D.h"
#include "Device/Histo/IOFactory.h"
#include "Device/Histo/SimulationResult.h"
#include "Device/Instrument/Instrument.h"
#include "Device/Mask/Ellipse.h"
#include "Device/Mask/Line.h"
#include "Device/Mask/Polygon.h"
#include "Device/Mask/Rectangle.h"
#include "Device/Mask/DetectorMask.h"
#include "Device/Resolution/IDetectorResolution.h"
#include "Device/Resolution/ResolutionFunction2DGaussian.h"
%}

%import(module="libBornAgainFit") "Fit/Param/AttLimits.h"
%import(module="libBornAgainFit") "Fit/Param/Attributes.h"
%import(module="libBornAgainFit") "Fit/Param/RealLimits.h"
%import(module="libBornAgainFit") "Fit/Param/Parameters.h"
%import(module="libBornAgainFit") "Fit/Param/Parameter.h"

%include "fromBase.i"
%include "fromParam.i"

// ownership
%newobject SimulationResult::histogram2d(Axes::Coords units_type = Axes::Coords::UNDEFINED) const;

%newobject IOFactory::readPowerfield(const std::string& file_name);
%newobject IOFactory::readIntensityData(const std::string& file_name);

%newobject DetectorMask::createHistogram() const;

%newobject DataUtils::Data::importArrayToPowerfield;
%newobject IHistogram::createFrom(const std::string& filename);
%newobject IHistogram::createFrom(const std::vector<std::vector<double>>& data);

%include "Device/Data/Powerfield.h"
%template(IntensityData) Powerfield<double>;
%include "Device/Data/DataUtils.h"

%include "Device/Beam/Beam.h"
%include "Device/Beam/IFootprintFactor.h"
%include "Device/Beam/FootprintGauss.h"
%include "Device/Beam/FootprintSquare.h"
%include "Device/Mask/IShape2D.h"
%include "Device/Mask/Ellipse.h"
%include "Device/Mask/Line.h"
%include "Device/Mask/Polygon.h"
%include "Device/Mask/Rectangle.h"
%include "Device/Resolution/IDetectorResolution.h"
%include "Device/Resolution/IResolutionFunction2D.h"
%include "Device/Resolution/ResolutionFunction2DGaussian.h"

%include "Device/Coord/Axes.h"

%include "Device/Mask/DetectorMask.h"
%include "Device/Detector/IDetector.h"
%include "Device/Detector/IDetector2D.h"
%include "Device/Detector/RectangularDetector.h"
%include "Device/Detector/SphericalDetector.h"

%include "Device/Instrument/Instrument.h"

%include "Device/Histo/HistoUtils.h"
%include "Device/Histo/IHistogram.h"
%include "Device/Histo/Histogram1D.h"
%include "Device/Histo/Histogram2D.h"
%include "Device/Histo/IOFactory.h"
%include "Device/Histo/SimulationResult.h"
